# Cross-species ChIPseq analysis

## Whole Genome Alignment

__Email from Camille Berthelot:__

We have run into a similar problem with non-model species in a recent project.
Here is the pipeline that we have had good success with, which is very similar to the conservation pipeline used by UCSC:

- build a custom whole-genome alignment between the dunnart and mouse genomes with Lastz
- produce the chains and nets for this alignment (e.g. hierarchical organisation of aligned regions to get a 1-to-1 alignment over the whole genomes)
- use LiftOver to map your dunnart regions of interest to mouse (and reciprocally)

We have benchmarked this pipeline against the one we used in the 20 mammals Cell paper, and there was almost no difference in the recovered regions.

This however assumes that you have a good grip on bioinformatics and access to sufficient computational power, as building alignments is quite intensive. There are a number of online tutorials to build the alignment and nets using Lastz:
http://genomewiki.ucsc.edu/index.php/Whole_genome_alignment_howto
https://www.bioconductor.org/packages/release/bioc/vignettes/CNEr/inst/doc/PairwiseWholeGenomeAlignment.html
https://github.com/hillerlab/GenomeAlignmentTools (more fine-tuned and advanced)

__Methods from Hecker & Hiller 2020 Whole Genome Alignment:__
Going to try this method.

To compute pairwise and multiple genome alignments, we used the human hg38 assembly as the reference (Supplementary Fig. 1 shows the entire workflow). We first built pairwise alignments between human and a query species using lastz and axtChain to compute co-linear alignment chains [82]. To align placental mammals, we used previously determined lastz parameters (K = 2400, L = 3000, Y = 9400, H = 2000, and the lastz default scoring matrix) that have a sufficient sensitivity to capture orthologous exons [16]. To align chimpanzee, bonobo, and gorilla, we changed the lastz parameters (K = 4500 and L = 4500).

After building chains, we applied RepeatFiller (RRID:SCR_017414), a method that performs another round of local alignment, considering unaligning regions ≤20 kb in size that are bounded by co-linear alignment blocks up- and downstream. RepeatFiller removes any repeat masking from the unaligned region and is therefore able to detect novel alignments between repetitive regions. We have previously shown that RepeatFiller detects several megabases of aligning repetitive sequences that would be missed otherwise. After RepeatFiller, we applied chainCleaner with parameters -LRfoldThreshold = 2.5 -doPairs -LRfoldThresholdPairs = 10 -maxPairDistance = 10000 -maxSuspectScore = 100000 -minBrokenChainScore = 75000 to improve alignment specificity. Pairwise alignment chains were converted into alignment nets using a modified version of chainNet that computes real scores of partial nets. Nets were filtered using NetFilterNonNested.perl with parameters -doUCSCSynFilter -keepSynNetsWithScore 5000 -keepInvNetsWithScore 5000, which applies the UCSC “syntenic net” score thresholds (minTopScore of 300000 and minSynScore of 200000) and keeps nested nets that align to the same locus (inversions or local translocations; net type “inv” or “syn” according to netClass) if they score ≥5,000. For the Mongolian gerbil, tarsier, Malayan flying lemur, sperm whale, Przewalski's horse, Weddell seal, Malayan pangolin, Chinese pangolin, Hoffmann's two-fingered sloth, and Cape rock hyrax that have genome assemblies with a scaffold N50 ≤1,000,000 and a contig N50 ≤100,000, we just required that nets have a score ≥100,000. For marsupials and platypus, we lowered the score threshold for nets to 10,000 and kept inv or syn nets with scores ≥3,000. Next, we used the filtered nets to compute a human-referenced multiple genome alignment with MULTIZ-tba. Finally, to distinguish between unaligning genomic regions that are truly diverged and genomic regions that do not align because they overlap assembly gaps in the query genome [83], we post-processed the multiple-genome alignment and removed all unaligning regions (e-lines in a maf block) that either overlap an assembly gap in the respective query genome(s) or are not covered by any alignment chain.

The main difference between this 120-mammal alignment and our previous 144-vertebrate alignment [16] is that the former focuses entirely on mammals and includes many new species (120 vs 74 mammals, see Supplementary Table 1). In addition, we updated genome assemblies of 12 species that were already included in the previous alignment (species are marked in Supplementary Table 1). Finally, the 120-mammal alignment used RepeatFiller to improve the completeness of alignments between repetitive regions.

__To align non-placental mammals, we used K = 2400, L = 3000, Y = 3400, H = 2000 and the HoxD55 scoring matrix.__

MASKING: Both genomes have to be repeatmasked and masked Tandem Repeat Finder (trf) first (thanks to Hiram for pointing this out)
ALIGNING: The two genomes are aligned with BLASTZ (we don't use blastz's own chaining, see discussion (angie)). This generates lav-files, which have to be converted to psl (lavToPsl)
CHAINING: Two matching alignments next to each other are joined into one fragment if they are close enough (axtChain). As every genomic fragment can match with several others, we keep only the longest chains : first do axtSort then filter with axtBest (more info on the mailing list)
NETTING: Group blocks of chained alignments into longer stretches of synteny (netChain)
MAF'ING: From the synteny-files (positions), get the sequences and re-create alignments
PhastCons: Using the maf-files, calculate the strength of conservation for every base, similar to a Vista- or protein Conservation plot, but applicable to multiple alignments


### Preparation

#### Repeat mask dunnart genome

????

#### Create .2bit and .sizes files

```
faToTwoBit ../../dunnart/genomes/Scras_dunnart_assem1.0_pb-ont-illsr_flyeassem_red-rd-scfitr2_pil2xwgs2_60chr.fasta smiCra1.2bit
```

```
twoBitInfo smiCra1.2bit stdout | sort -k2rn > smiCra1.chrom.sizes
```

#### mm10 target genome
http://hgdownload.cse.ucsc.edu/goldenpath/mm10/bigZips/mm10.2bit

__mm10.2bit__ - contains the complete mouse/mm10 genome sequence in the 2bit file format.  Repeats from __RepeatMasker__ and __Tandem Repeats Finder__ (with period of 12 or less) are shown in lower case; non-repeating sequence is shown in upper case.  


### lastZ

To align placental mammals, we used previously determined lastz parameters (K = 2400, L = 3000, Y = 9400, H = 2000, and the lastz default scor- ing matrix) that have a sufficient sensitivity to capture orthol- ogous exons

To align placental mammals, we used the lastz alignment parameters K = 2400, L = 3000, Y = 9400, H = 2000 and the lastz default scoring matrix, correspond- ing to parameter set 2 in Table 1. To align non-placental vertebrates, we used K = 2400, L = 3000, Y = 3400, H = 2000 and the HoxD55 scoring matrix. Citation: Increased alignment sensitivity improves the usage of genome alignments for comparative gene annotation. Nucleic Acids Res. 2017;45(14):8369–77.

### axtChain
### RepeatFiller
### chainCleaner
### chainNet
### NetFilterNonNested
### MultiZ (roast)
